pub struct ScaleSequence {
pub tonic: PitchClass,
pub scale: ScaleKind,
pub direction: SequenceDirection,
pub octave: Octave,
pub length: usize,
}Expand description
ScaleSequences allow for the creation of note-mapping patterns from common musical scales
Fields
tonic: PitchClassthe tonic of the scale
scale: ScaleKindthe supported scale kind, which determines intervals used
direction: SequenceDirectionare the notes ascending or descending?
octave: Octavewhat is the octave of the tonic where the sequence begins?
length: usizehow notes do we want the sequence to produce?
Implementations
Sourceimpl ScaleSequence
impl ScaleSequence
Sourcepub fn as_midi_notes(&self) -> Vec<u8> ⓘ
pub fn as_midi_notes(&self) -> Vec<u8> ⓘ
Uses the field config values from self to produce a Vec